@@ -2,7 +2,7 @@
     SPDX-FileCopyrightText: 2006 Kevin Ottens <ervin@kde.org>
     SPDX-FileCopyrightText: 2014 Alejandro Fiestas Olivares <afiestas@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-only
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef SOLID_HARDWARE_H
@@ -18,13 +18,18 @@ class SolidHardware : public QCoreApplication
 {
     Q_OBJECT
 public:
-    SolidHardware(int &argc, char **argv) : QCoreApplication(argc, argv), m_error(0) {}
+    SolidHardware(int &argc, char **argv)
+        : QCoreApplication(argc, argv)
+        , m_error(0)
+    {
+    }
 
     bool hwList(bool interfaces, bool system);
     bool hwCapabilities(const QString &udi);
     bool hwProperties(const QString &udi);
     bool hwQuery(const QString &parentUdi, const QString &query);
     bool listen();
+    bool monitor(const QString &udi);
 
     enum VolumeCallType { Mount, Unmount, Eject };
     bool hwVolumeCall(VolumeCallType type, const QString &udi);
@@ -40,6 +45,4 @@ private Q_SLOTS:
     void deviceRemoved(const QString &udi);
 };
 
-Q_DECLARE_METATYPE(QList<int>)
-
 #endif // SOLID_HARDWARE_H
